<h1 align="center" name="pywebio-en">PyWebIO Battery</h1>
<p align="center">
    <em>Utilities that help write PyWebIO apps quickly and easily.</em>
</p>
<p align="center">
    <a href="https://codecov.io/gh/wang0618/pywebio-battery">
        <img src="https://codecov.io/gh/wang0618/pywebio-battery/branch/main/graph/badge.svg?token=mSKUYxL5d1"/>
    </a>
    <a href="https://pypi.org/project/pywebio-battery/">
        <img src="https://img.shields.io/pypi/v/pywebio-battery?colorB=brightgreen" alt="Package version">
    </a>
    <a href="https://pypi.org/project/pywebio-battery/">
        <img src="https://img.shields.io/badge/python->%3D%203.5.2-brightgreen" alt="Python Version">
    </a>
    <a href="https://lgtm.com/projects/g/wang0618/pywebio-battery/context:python">
        <img src="https://img.shields.io/lgtm/grade/python/github/wang0618/pywebio-battery.svg?colorB=brightgreen" alt="Python code quality">
    </a>
    <a href="https://github.com/wang0618/pywebio-battery/blob/master/LICENSE">
        <img src="https://img.shields.io/github/license/wang0618/pywebio-battery.svg" alt="License">
    </a>
    <br/>
    <a href="https://pywebio.readthedocs.io/en/latest/battery.html">[Document]</a>
</p>


## Installation

```bash
pip3 install -U pywebio-battery
```

## Usage

```python
import pywebio_battery as battery

battery.xxx()
```

## Resources
 
 - Document: https://pywebio.readthedocs.io/en/latest/battery.html
 - Need help? Make a new discussion on [PyWebIO Discussions](https://github.com/pywebio/PyWebIO/discussions)
 - Bug report: https://github.com/pywebio/PyWebIO/issues